import json
import pandas as pd
import matplotlib.pyplot as plt

# Read json file
with open("redispatch08-2022.json") as f:
    data =json.load(f)

# create pandas dataframe on the list of "communeBottleneckMinutes"
df = pd.json_normalize(data, record_path=["communeBottleneckMinutes"])

# calculate the total amount of Bottleneck minutes
total_bottleneck_minutes = df["totalBottleneckMinutes"].sum()
print("Total amount of bottleneck minutes over all communes: ", total_bottleneck_minutes)

# Get the relative amount of Bottleneck minutes compared to the total amount
df["relativeBottleneckToTotal"] = df["totalBottleneckMinutes"] / total_bottleneck_minutes

# output the top ten highest bottlenecks
df_top_ten = df.sort_values("totalBottleneckMinutes", ascending=False, ignore_index=True).take(range(10))
print("Top Ten longest Bottlenecks\n")
print(df_top_ten)

# Create a scatterplot
plt.scatter(df["totalEegPlants"], df["totalBottleneckMinutes"])
plt.title("Redispatch 08.2022")
plt.xlabel("Total EEG Plants")
plt.ylabel("Total Bottleneck Minutes")
plt.savefig("scatterplot.png")