import plotly.express as px
import pandas as pd
import json
import time

# Read json file
with open("einrichtungen.json") as f:
    data =json.load(f)

# create pandas dataframe on the list of "communeBottleneckMinutes"
df = pd.json_normalize(data, meta=[["address", "longitude"], ["address", "latitude"]])
# drop unwanted columns and rows with missing coordinates
df.drop(columns=["bilder", "imageIds"], inplace=True)
df.dropna(how='any', subset="address.latitude", inplace=True)

# Fill NaN values with a String
df.fillna("Nicht angegeben", inplace=True)

# Convert the timestamp to hours
df["openingHoursFrom"] = df["openingHoursFrom"].apply(lambda x: x/(60*60*1000))
df["openingHoursTo"] = df["openingHoursTo"].apply(lambda x: x/(60*60*1000))

# color_scale = [(0, 'orange'), (1,'red')]

# Create the map
fig = px.scatter_mapbox(df, #.loc[df["religioeseAusrichtung"] != 0]
                        lat="address.latitude", 
                        lon="address.longitude", 
                        hover_name="name", 
                        hover_data=df.columns,
                        color="educationalConcept",
                        # color_continuous_scale=color_scale,
                        zoom=8, 
                        height=800,
                        width=1700)

# Use Openstreetmap as map
fig.update_layout(mapbox_style="open-street-map")
# Remove the margin on the right, top, left and bottom side
fig.update_layout(margin={"r":0,"t":0,"l":0,"b":0})
fig.show()